ACCESS = {
    "valid": True,
    "consent_expiration_date": "2026-01-14T15:32:38",
    "call_number": 7,
    "quota_reached": False,
    "quota_limit": 50,
    "quota_reset_at": "2023-01-14T23:59:59.999999",
    "last_call": "2023-01-07T13:58:24.532501",
    "ban": False,
}

INVALID_ACCESS = {
    "valid": False,
    "information": "Vous avez dépassé votre quota journalier (50)",
    "consent_expiration_date": "2026-01-14T15:32:38",
    "call_number": 65,
    "quota_reached": True,
    "quota_limit": 50,
    "quota_reset_at": "2023-01-14T23:59:59.999999",
    "last_call": "2023-01-07T13:58:24.532501",
    "ban": False,
}
TEMPO = {"2023-3-1": "blue", "2023-3-2": "red", "2023-3-3": "blue"}
INVALID_ECOWATT = {
    "detail": "Pas de données disponible entre la date du 2023-01-22 00:00:00 et 2023-01-22 00:00:00"  # noqa
}
ECOWATT = {
    "2023-01-22": {
        "value": 1,
        "message": "Pas d’alerte.",
        "detail": {
            "2023-01-23 00:00:00": 1,
            "2023-01-23 01:00:00": 1,
            "2023-01-23 02:00:00": 1,
            "2023-01-23 03:00:00": 1,
            "2023-01-23 04:00:00": 1,
            "2023-01-23 05:00:00": 1,
            "2023-01-23 06:00:00": 1,
            "2023-01-23 07:00:00": 1,
            "2023-01-23 08:00:00": 1,
            "2023-01-23 09:00:00": 1,
            "2023-01-23 10:00:00": 1,
            "2023-01-23 11:00:00": 1,
            "2023-01-23 12:00:00": 1,
            "2023-01-23 13:00:00": 1,
            "2023-01-23 14:00:00": 1,
            "2023-01-23 15:00:00": 1,
            "2023-01-23 16:00:00": 1,
            "2023-01-23 17:00:00": 1,
            "2023-01-23 18:00:00": 1,
            "2023-01-23 19:00:00": 1,
            "2023-01-23 20:00:00": 1,
            "2023-01-23 21:00:00": 1,
            "2023-01-23 22:00:00": 1,
            "2023-01-23 23:00:00": 1,
        },
    },
    "2023-01-23": {
        "value": 1,
        "message": "Pas d’alerte.",
        "detail": {
            "2023-01-24 00:00:00": 1,
            "2023-01-24 01:00:00": 1,
            "2023-01-24 02:00:00": 1,
            "2023-01-24 03:00:00": 1,
            "2023-01-24 04:00:00": 1,
            "2023-01-24 05:00:00": 1,
            "2023-01-24 06:00:00": 1,
            "2023-01-24 07:00:00": 1,
            "2023-01-24 08:00:00": 1,
            "2023-01-24 09:00:00": 1,
            "2023-01-24 10:00:00": 1,
            "2023-01-24 11:00:00": 1,
            "2023-01-24 12:00:00": 1,
            "2023-01-24 13:00:00": 1,
            "2023-01-24 14:00:00": 1,
            "2023-01-24 15:00:00": 1,
            "2023-01-24 16:00:00": 1,
            "2023-01-24 17:00:00": 1,
            "2023-01-24 18:00:00": 1,
            "2023-01-24 19:00:00": 1,
            "2023-01-24 20:00:00": 1,
            "2023-01-24 21:00:00": 1,
            "2023-01-24 22:00:00": 1,
            "2023-01-24 23:00:00": 1,
        },
    },
}


DATASET_30 = {
    "meter_reading": {
        "usage_point_id": "09171201102829",
        "start": "2023-03-01",
        "end": "2023-03-08",
        "quality": "BRUT",
        "reading_type": {
            "measurement_kind": "power",
            "unit": "W",
            "aggregate": "average",
        },
        "interval_reading": [
            {
                "value": "1344",
                "date": "2023-03-01 00:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1248",
                "date": "2023-03-01 01:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1236",
                "date": "2023-03-01 01:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2158",
                "date": "2023-03-01 02:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2388",
                "date": "2023-03-01 02:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2700",
                "date": "2023-03-01 03:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3428",
                "date": "2023-03-01 03:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "5826",
                "date": "2023-03-01 04:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "6696",
                "date": "2023-03-01 04:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "6776",
                "date": "2023-03-01 05:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "6146",
                "date": "2023-03-01 05:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "5888",
                "date": "2023-03-01 06:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "6402",
                "date": "2023-03-01 06:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "6300",
                "date": "2023-03-01 07:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "6536",
                "date": "2023-03-01 07:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "6230",
                "date": "2023-03-01 08:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "6614",
                "date": "2023-03-01 08:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "5342",
                "date": "2023-03-01 09:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3182",
                "date": "2023-03-01 09:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3174",
                "date": "2023-03-01 10:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1298",
                "date": "2023-03-01 10:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2136",
                "date": "2023-03-01 11:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1994",
                "date": "2023-03-01 11:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1968",
                "date": "2023-03-01 12:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1942",
                "date": "2023-03-01 12:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2078",
                "date": "2023-03-01 13:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1402",
                "date": "2023-03-01 13:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1540",
                "date": "2023-03-01 14:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2346",
                "date": "2023-03-01 14:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1722",
                "date": "2023-03-01 15:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1236",
                "date": "2023-03-01 15:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "4296",
                "date": "2023-03-01 16:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "4806",
                "date": "2023-03-01 16:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "4186",
                "date": "2023-03-01 17:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "7068",
                "date": "2023-03-01 17:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "4326",
                "date": "2023-03-01 18:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "5048",
                "date": "2023-03-01 18:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "4460",
                "date": "2023-03-01 19:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2324",
                "date": "2023-03-01 19:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "536",
                "date": "2023-03-01 20:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "734",
                "date": "2023-03-01 20:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "544",
                "date": "2023-03-01 21:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "494",
                "date": "2023-03-01 21:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "486",
                "date": "2023-03-01 22:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1204",
                "date": "2023-03-01 22:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2220",
                "date": "2023-03-01 23:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2258",
                "date": "2023-03-01 23:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "852",
                "date": "2023-03-02 00:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "342",
                "date": "2023-03-02 00:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "316",
                "date": "2023-03-02 01:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "686",
                "date": "2023-03-02 01:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1978",
                "date": "2023-03-02 02:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3368",
                "date": "2023-03-02 02:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2650",
                "date": "2023-03-02 03:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2530",
                "date": "2023-03-02 03:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3428",
                "date": "2023-03-02 04:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "5390",
                "date": "2023-03-02 04:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "7398",
                "date": "2023-03-02 05:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "5714",
                "date": "2023-03-02 05:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "5402",
                "date": "2023-03-02 06:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "5452",
                "date": "2023-03-02 06:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "5548",
                "date": "2023-03-02 07:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3716",
                "date": "2023-03-02 07:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "466",
                "date": "2023-03-02 08:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1812",
                "date": "2023-03-02 08:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "4200",
                "date": "2023-03-02 09:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "6480",
                "date": "2023-03-02 09:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "6304",
                "date": "2023-03-02 10:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "4766",
                "date": "2023-03-02 10:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3930",
                "date": "2023-03-02 11:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2898",
                "date": "2023-03-02 11:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2024",
                "date": "2023-03-02 12:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "318",
                "date": "2023-03-02 12:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "312",
                "date": "2023-03-02 13:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "430",
                "date": "2023-03-02 13:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1274",
                "date": "2023-03-02 14:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1152",
                "date": "2023-03-02 14:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1144",
                "date": "2023-03-02 15:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1184",
                "date": "2023-03-02 15:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2378",
                "date": "2023-03-02 16:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2516",
                "date": "2023-03-02 16:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2680",
                "date": "2023-03-02 17:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "4602",
                "date": "2023-03-02 17:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "5178",
                "date": "2023-03-02 18:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "6940",
                "date": "2023-03-02 18:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "6404",
                "date": "2023-03-02 19:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "4928",
                "date": "2023-03-02 19:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2234",
                "date": "2023-03-02 20:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1458",
                "date": "2023-03-02 20:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "574",
                "date": "2023-03-02 21:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "544",
                "date": "2023-03-02 21:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "516",
                "date": "2023-03-02 22:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "528",
                "date": "2023-03-02 22:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "486",
                "date": "2023-03-02 23:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "462",
                "date": "2023-03-02 23:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2320",
                "date": "2023-03-03 00:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3020",
                "date": "2023-03-03 00:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2786",
                "date": "2023-03-03 01:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1168",
                "date": "2023-03-03 01:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "1952",
                "date": "2023-03-03 02:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2020",
                "date": "2023-03-03 02:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2452",
                "date": "2023-03-03 03:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2446",
                "date": "2023-03-03 03:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2536",
                "date": "2023-03-03 04:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3560",
                "date": "2023-03-03 04:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2760",
                "date": "2023-03-03 05:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3364",
                "date": "2023-03-03 05:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3962",
                "date": "2023-03-03 06:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "8168",
                "date": "2023-03-03 06:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "6328",
                "date": "2023-03-03 07:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "5606",
                "date": "2023-03-03 07:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "5390",
                "date": "2023-03-03 08:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "4128",
                "date": "2023-03-03 08:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3826",
                "date": "2023-03-03 09:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2562",
                "date": "2023-03-03 09:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3118",
                "date": "2023-03-03 10:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3626",
                "date": "2023-03-03 10:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3758",
                "date": "2023-03-03 11:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3396",
                "date": "2023-03-03 11:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3300",
                "date": "2023-03-03 12:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "4046",
                "date": "2023-03-03 12:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "4262",
                "date": "2023-03-03 13:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "4832",
                "date": "2023-03-03 13:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "4126",
                "date": "2023-03-03 14:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "4006",
                "date": "2023-03-03 14:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3838",
                "date": "2023-03-03 15:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3504",
                "date": "2023-03-03 15:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2860",
                "date": "2023-03-03 16:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2834",
                "date": "2023-03-03 16:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2728",
                "date": "2023-03-03 17:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2708",
                "date": "2023-03-03 17:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2832",
                "date": "2023-03-03 18:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2122",
                "date": "2023-03-03 18:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2246",
                "date": "2023-03-03 19:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "7288",
                "date": "2023-03-03 19:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "5208",
                "date": "2023-03-03 20:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "3492",
                "date": "2023-03-03 20:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2662",
                "date": "2023-03-03 21:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2256",
                "date": "2023-03-03 21:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2158",
                "date": "2023-03-03 22:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2162",
                "date": "2023-03-03 22:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2216",
                "date": "2023-03-03 23:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2168",
                "date": "2023-03-03 23:30:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
            {
                "value": "2158",
                "date": "2023-03-04 00:00:00",
                "interval_length": "PT30M",
                "measure_type": "B",
            },
        ],
    }
}

DATASET_DAILY_COMPARE = {
    "meter_reading": {
        "usage_point_id": "012345",
        "start": "2022-03-08",
        "end": "2023-03-08",
        "quality": "BRUT",
        "reading_type": {
            "measurement_kind": "energy",
            "measuring_period": "P1D",
            "unit": "Wh",
            "aggregate": "sum",
        },
        "interval_reading": [
            {"value": "77559", "date": "2023-03-01"},
            {"value": "68680", "date": "2023-03-02"},
            {"value": "81972", "date": "2023-03-03"},
        ],
    }
}

DATASET_DAILY = {
    "meter_reading": {
        "usage_point_id": "012345",
        "start": "2022-03-08",
        "end": "2023-03-08",
        "quality": "BRUT",
        "reading_type": {
            "measurement_kind": "energy",
            "measuring_period": "P1D",
            "unit": "Wh",
            "aggregate": "sum",
        },
        "interval_reading": [
            {"value": "42045", "date": "2022-03-08"},
            {"value": "32464", "date": "2022-03-09"},
            {"value": "38336", "date": "2022-03-10"},
            {"value": "62200", "date": "2022-03-11"},
            {"value": "67007", "date": "2022-03-12"},
            {"value": "66275", "date": "2022-03-13"},
            {"value": "72346", "date": "2022-03-14"},
            {"value": "42694", "date": "2022-03-15"},
            {"value": "48597", "date": "2022-03-16"},
            {"value": "56229", "date": "2022-03-17"},
            {"value": "63071", "date": "2022-03-18"},
            {"value": "55481", "date": "2022-03-19"},
            {"value": "29945", "date": "2022-03-20"},
            {"value": "28481", "date": "2022-03-21"},
            {"value": "23795", "date": "2022-03-22"},
            {"value": "35631", "date": "2022-03-23"},
            {"value": "20513", "date": "2022-03-24"},
            {"value": "27899", "date": "2022-03-25"},
            {"value": "47680", "date": "2022-03-26"},
            {"value": "17062", "date": "2022-03-27"},
            {"value": "18941", "date": "2022-03-28"},
            {"value": "12112", "date": "2022-03-29"},
            {"value": "30367", "date": "2022-03-30"},
            {"value": "47756", "date": "2022-03-31"},
            {"value": "110531", "date": "2022-04-01"},
            {"value": "84699", "date": "2022-04-02"},
            {"value": "63727", "date": "2022-04-03"},
            {"value": "34163", "date": "2022-04-04"},
            {"value": "18876", "date": "2022-04-05"},
            {"value": "29905", "date": "2022-04-06"},
            {"value": "18385", "date": "2022-04-07"},
            {"value": "34016", "date": "2022-04-08"},
            {"value": "53606", "date": "2022-04-09"},
            {"value": "43162", "date": "2022-04-10"},
            {"value": "20344", "date": "2022-04-11"},
            {"value": "13466", "date": "2022-04-12"},
            {"value": "21524", "date": "2022-04-13"},
            {"value": "51276", "date": "2022-04-14"},
            {"value": "24990", "date": "2022-04-15"},
            {"value": "24035", "date": "2022-04-16"},
            {"value": "8214", "date": "2022-04-17"},
            {"value": "10881", "date": "2022-04-18"},
            {"value": "13050", "date": "2022-04-19"},
            {"value": "12117", "date": "2022-04-20"},
            {"value": "28203", "date": "2022-04-21"},
            {"value": "43742", "date": "2022-04-22"},
            {"value": "28486", "date": "2022-04-23"},
            {"value": "12803", "date": "2022-04-24"},
            {"value": "16624", "date": "2022-04-25"},
            {"value": "10443", "date": "2022-04-26"},
            {"value": "11876", "date": "2022-04-27"},
            {"value": "37394", "date": "2022-04-28"},
            {"value": "35961", "date": "2022-04-29"},
            {"value": "35094", "date": "2022-04-30"},
            {"value": "39369", "date": "2022-05-01"},
            {"value": "30591", "date": "2022-05-02"},
            {"value": "29264", "date": "2022-05-03"},
            {"value": "31564", "date": "2022-05-04"},
            {"value": "29668", "date": "2022-05-05"},
            {"value": "30170", "date": "2022-05-06"},
            {"value": "28486", "date": "2022-05-07"},
            {"value": "14252", "date": "2022-05-08"},
            {"value": "12116", "date": "2022-05-09"},
            {"value": "11748", "date": "2022-05-10"},
            {"value": "11786", "date": "2022-05-11"},
            {"value": "10678", "date": "2022-05-12"},
            {"value": "19073", "date": "2022-05-13"},
            {"value": "40687", "date": "2022-05-14"},
            {"value": "20733", "date": "2022-05-15"},
            {"value": "15693", "date": "2022-05-16"},
            {"value": "13745", "date": "2022-05-17"},
            {"value": "13569", "date": "2022-05-18"},
            {"value": "13637", "date": "2022-05-19"},
            {"value": "11971", "date": "2022-05-20"},
            {"value": "12867", "date": "2022-05-21"},
            {"value": "39237", "date": "2022-05-22"},
            {"value": "28513", "date": "2022-05-23"},
            {"value": "25950", "date": "2022-05-24"},
            {"value": "26772", "date": "2022-05-25"},
            {"value": "15978", "date": "2022-05-26"},
            {"value": "6030", "date": "2022-05-27"},
            {"value": "5984", "date": "2022-05-28"},
            {"value": "7713", "date": "2022-05-29"},
            {"value": "13827", "date": "2022-05-30"},
            {"value": "12900", "date": "2022-05-31"},
            {"value": "11668", "date": "2022-06-01"},
            {"value": "11182", "date": "2022-06-02"},
            {"value": "40810", "date": "2022-06-03"},
            {"value": "23410", "date": "2022-06-04"},
            {"value": "27331", "date": "2022-06-05"},
            {"value": "27887", "date": "2022-06-06"},
            {"value": "11670", "date": "2022-06-07"},
            {"value": "11043", "date": "2022-06-08"},
            {"value": "11379", "date": "2022-06-09"},
            {"value": "33707", "date": "2022-06-10"},
            {"value": "27015", "date": "2022-06-11"},
            {"value": "20701", "date": "2022-06-12"},
            {"value": "17744", "date": "2022-06-13"},
            {"value": "9980", "date": "2022-06-14"},
            {"value": "15880", "date": "2022-06-15"},
            {"value": "29435", "date": "2022-06-16"},
            {"value": "20656", "date": "2022-06-17"},
            {"value": "21027", "date": "2022-06-18"},
            {"value": "14567", "date": "2022-06-19"},
            {"value": "13811", "date": "2022-06-20"},
            {"value": "10191", "date": "2022-06-21"},
            {"value": "14417", "date": "2022-06-22"},
            {"value": "10043", "date": "2022-06-23"},
            {"value": "21743", "date": "2022-06-24"},
            {"value": "36662", "date": "2022-06-25"},
            {"value": "23103", "date": "2022-06-26"},
            {"value": "13195", "date": "2022-06-27"},
            {"value": "10598", "date": "2022-06-28"},
            {"value": "11455", "date": "2022-06-29"},
            {"value": "11333", "date": "2022-06-30"},
            {"value": "18100", "date": "2022-07-01"},
            {"value": "38566", "date": "2022-07-02"},
            {"value": "14843", "date": "2022-07-03"},
            {"value": "11512", "date": "2022-07-04"},
            {"value": "12482", "date": "2022-07-05"},
            {"value": "12491", "date": "2022-07-06"},
            {"value": "10424", "date": "2022-07-07"},
            {"value": "18148", "date": "2022-07-08"},
            {"value": "36765", "date": "2022-07-09"},
            {"value": "24978", "date": "2022-07-10"},
            {"value": "24332", "date": "2022-07-11"},
            {"value": "20499", "date": "2022-07-12"},
            {"value": "24372", "date": "2022-07-13"},
            {"value": "24725", "date": "2022-07-14"},
            {"value": "28339", "date": "2022-07-15"},
            {"value": "21653", "date": "2022-07-16"},
            {"value": "16664", "date": "2022-07-17"},
            {"value": "18723", "date": "2022-07-18"},
            {"value": "17431", "date": "2022-07-19"},
            {"value": "14103", "date": "2022-07-20"},
            {"value": "13067", "date": "2022-07-21"},
            {"value": "14842", "date": "2022-07-22"},
            {"value": "9722", "date": "2022-07-23"},
            {"value": "8063", "date": "2022-07-24"},
            {"value": "8204", "date": "2022-07-25"},
            {"value": "7069", "date": "2022-07-26"},
            {"value": "7139", "date": "2022-07-27"},
            {"value": "7003", "date": "2022-07-28"},
            {"value": "6824", "date": "2022-07-29"},
            {"value": "6913", "date": "2022-07-30"},
            {"value": "6977", "date": "2022-07-31"},
            {"value": "6980", "date": "2022-08-01"},
            {"value": "7503", "date": "2022-08-02"},
            {"value": "7550", "date": "2022-08-03"},
            {"value": "10446", "date": "2022-08-04"},
            {"value": "9001", "date": "2022-08-05"},
            {"value": "14513", "date": "2022-08-06"},
            {"value": "12210", "date": "2022-08-07"},
            {"value": "12901", "date": "2022-08-08"},
            {"value": "13515", "date": "2022-08-09"},
            {"value": "15792", "date": "2022-08-10"},
            {"value": "14318", "date": "2022-08-11"},
            {"value": "16293", "date": "2022-08-12"},
            {"value": "16197", "date": "2022-08-13"},
            {"value": "10804", "date": "2022-08-14"},
            {"value": "9342", "date": "2022-08-15"},
            {"value": "11076", "date": "2022-08-16"},
            {"value": "9736", "date": "2022-08-17"},
            {"value": "10321", "date": "2022-08-18"},
            {"value": "11983", "date": "2022-08-19"},
            {"value": "10230", "date": "2022-08-20"},
            {"value": "13117", "date": "2022-08-21"},
            {"value": "11461", "date": "2022-08-22"},
            {"value": "10081", "date": "2022-08-23"},
            {"value": "10102", "date": "2022-08-24"},
            {"value": "9830", "date": "2022-08-25"},
            {"value": "13571", "date": "2022-08-26"},
            {"value": "12483", "date": "2022-08-27"},
            {"value": "11738", "date": "2022-08-28"},
            {"value": "12414", "date": "2022-08-29"},
            {"value": "13193", "date": "2022-08-30"},
            {"value": "11700", "date": "2022-08-31"},
            {"value": "11859", "date": "2022-09-01"},
            {"value": "10105", "date": "2022-09-02"},
            {"value": "10309", "date": "2022-09-03"},
            {"value": "12241", "date": "2022-09-04"},
            {"value": "10957", "date": "2022-09-05"},
            {"value": "11045", "date": "2022-09-06"},
            {"value": "12026", "date": "2022-09-07"},
            {"value": "11643", "date": "2022-09-08"},
            {"value": "10056", "date": "2022-09-09"},
            {"value": "12019", "date": "2022-09-10"},
            {"value": "13394", "date": "2022-09-11"},
            {"value": "13096", "date": "2022-09-12"},
            {"value": "11942", "date": "2022-09-13"},
            {"value": "13034", "date": "2022-09-14"},
            {"value": "10723", "date": "2022-09-15"},
            {"value": "11627", "date": "2022-09-16"},
            {"value": "10343", "date": "2022-09-17"},
            {"value": "12775", "date": "2022-09-18"},
            {"value": "10436", "date": "2022-09-19"},
            {"value": "12261", "date": "2022-09-20"},
            {"value": "10729", "date": "2022-09-21"},
            {"value": "12484", "date": "2022-09-22"},
            {"value": "12867", "date": "2022-09-23"},
            {"value": "13906", "date": "2022-09-24"},
            {"value": "13955", "date": "2022-09-25"},
            {"value": "12665", "date": "2022-09-26"},
            {"value": "16707", "date": "2022-09-27"},
            {"value": "16116", "date": "2022-09-28"},
            {"value": "14523", "date": "2022-09-29"},
            {"value": "19063", "date": "2022-09-30"},
            {"value": "12306", "date": "2022-10-01"},
            {"value": "12834", "date": "2022-10-02"},
            {"value": "11564", "date": "2022-10-03"},
            {"value": "12104", "date": "2022-10-04"},
            {"value": "12318", "date": "2022-10-05"},
            {"value": "9879", "date": "2022-10-06"},
            {"value": "27562", "date": "2022-10-07"},
            {"value": "22653", "date": "2022-10-08"},
            {"value": "19398", "date": "2022-10-09"},
            {"value": "17060", "date": "2022-10-10"},
            {"value": "12024", "date": "2022-10-11"},
            {"value": "24244", "date": "2022-10-12"},
            {"value": "18550", "date": "2022-10-13"},
            {"value": "11560", "date": "2022-10-14"},
            {"value": "11521", "date": "2022-10-15"},
            {"value": "16156", "date": "2022-10-16"},
            {"value": "13458", "date": "2022-10-17"},
            {"value": "11841", "date": "2022-10-18"},
            {"value": "14742", "date": "2022-10-19"},
            {"value": "10121", "date": "2022-10-20"},
            {"value": "12001", "date": "2022-10-21"},
            {"value": "13350", "date": "2022-10-22"},
            {"value": "14905", "date": "2022-10-23"},
            {"value": "12021", "date": "2022-10-24"},
            {"value": "14562", "date": "2022-10-25"},
            {"value": "12258", "date": "2022-10-26"},
            {"value": "13415", "date": "2022-10-27"},
            {"value": "12518", "date": "2022-10-28"},
            {"value": "10087", "date": "2022-10-29"},
            {"value": "15166", "date": "2022-10-30"},
            {"value": "14948", "date": "2022-10-31"},
            {"value": "15974", "date": "2022-11-01"},
            {"value": "14468", "date": "2022-11-02"},
            {"value": "25567", "date": "2022-11-03"},
            {"value": "71332", "date": "2022-11-04"},
            {"value": "53982", "date": "2022-11-05"},
            {"value": "21724", "date": "2022-11-06"},
            {"value": "17845", "date": "2022-11-07"},
            {"value": "21017", "date": "2022-11-08"},
            {"value": "26524", "date": "2022-11-09"},
            {"value": "33179", "date": "2022-11-10"},
            {"value": "52574", "date": "2022-11-11"},
            {"value": "51679", "date": "2022-11-12"},
            {"value": "41285", "date": "2022-11-13"},
            {"value": "44696", "date": "2022-11-14"},
            {"value": "39779", "date": "2022-11-15"},
            {"value": "45433", "date": "2022-11-16"},
            {"value": "36854", "date": "2022-11-17"},
            {"value": "49886", "date": "2022-11-18"},
            {"value": "69287", "date": "2022-11-19"},
            {"value": "50766", "date": "2022-11-20"},
            {"value": "47665", "date": "2022-11-21"},
            {"value": "42152", "date": "2022-11-22"},
            {"value": "33432", "date": "2022-11-23"},
            {"value": "38033", "date": "2022-11-24"},
            {"value": "67428", "date": "2022-11-25"},
            {"value": "86672", "date": "2022-11-26"},
            {"value": "52789", "date": "2022-11-27"},
            {"value": "57302", "date": "2022-11-28"},
            {"value": "70239", "date": "2022-11-29"},
            {"value": "83360", "date": "2022-11-30"},
            {"value": "76308", "date": "2022-12-01"},
            {"value": "89797", "date": "2022-12-02"},
            {"value": "95270", "date": "2022-12-03"},
            {"value": "57781", "date": "2022-12-04"},
            {"value": "68680", "date": "2022-12-05"},
            {"value": "68480", "date": "2022-12-06"},
            {"value": "76276", "date": "2022-12-07"},
            {"value": "77603", "date": "2022-12-08"},
            {"value": "79436", "date": "2022-12-09"},
            {"value": "118017", "date": "2022-12-10"},
            {"value": "77760", "date": "2022-12-11"},
            {"value": "95261", "date": "2022-12-12"},
            {"value": "89256", "date": "2022-12-13"},
            {"value": "81311", "date": "2022-12-14"},
            {"value": "77010", "date": "2022-12-15"},
            {"value": "79682", "date": "2022-12-16"},
            {"value": "91343", "date": "2022-12-17"},
            {"value": "79944", "date": "2022-12-18"},
            {"value": "39709", "date": "2022-12-19"},
            {"value": "28593", "date": "2022-12-20"},
            {"value": "32422", "date": "2022-12-21"},
            {"value": "51303", "date": "2022-12-22"},
            {"value": "50221", "date": "2022-12-23"},
            {"value": "22985", "date": "2022-12-24"},
            {"value": "23539", "date": "2022-12-25"},
            {"value": "41136", "date": "2022-12-26"},
            {"value": "63474", "date": "2022-12-27"},
            {"value": "36757", "date": "2022-12-28"},
            {"value": "19919", "date": "2022-12-29"},
            {"value": "48482", "date": "2022-12-30"},
            {"value": "15136", "date": "2022-12-31"},
            {"value": "24830", "date": "2023-01-01"},
            {"value": "32093", "date": "2023-01-02"},
            {"value": "45514", "date": "2023-01-03"},
            {"value": "39174", "date": "2023-01-04"},
            {"value": "61507", "date": "2023-01-05"},
            {"value": "38979", "date": "2023-01-06"},
            {"value": "53811", "date": "2023-01-07"},
            {"value": "51159", "date": "2023-01-08"},
            {"value": "46791", "date": "2023-01-09"},
            {"value": "40350", "date": "2023-01-10"},
            {"value": "28709", "date": "2023-01-11"},
            {"value": "30520", "date": "2023-01-12"},
            {"value": "62033", "date": "2023-01-13"},
            {"value": "57914", "date": "2023-01-14"},
            {"value": "63941", "date": "2023-01-15"},
            {"value": "56766", "date": "2023-01-16"},
            {"value": "58281", "date": "2023-01-17"},
            {"value": "65878", "date": "2023-01-18"},
            {"value": "66051", "date": "2023-01-19"},
            {"value": "95568", "date": "2023-01-20"},
            {"value": "114160", "date": "2023-01-21"},
            {"value": "95948", "date": "2023-01-22"},
            {"value": "68854", "date": "2023-01-23"},
            {"value": "81149", "date": "2023-01-24"},
            {"value": "79730", "date": "2023-01-25"},
            {"value": "71958", "date": "2023-01-26"},
            {"value": "51133", "date": "2023-01-27"},
            {"value": "99263", "date": "2023-01-28"},
            {"value": "61042", "date": "2023-01-29"},
            {"value": "45184", "date": "2023-01-30"},
            {"value": "59826", "date": "2023-01-31"},
            {"value": "53820", "date": "2023-02-01"},
            {"value": "42051", "date": "2023-02-02"},
            {"value": "57205", "date": "2023-02-03"},
            {"value": "68347", "date": "2023-02-04"},
            {"value": "40913", "date": "2023-02-05"},
            {"value": "59397", "date": "2023-02-06"},
            {"value": "81915", "date": "2023-02-07"},
            {"value": "80208", "date": "2023-02-08"},
            {"value": "75895", "date": "2023-02-09"},
            {"value": "34320", "date": "2023-02-10"},
            {"value": "47758", "date": "2023-02-11"},
            {"value": "44986", "date": "2023-02-12"},
            {"value": "61731", "date": "2023-02-13"},
            {"value": "89207", "date": "2023-02-14"},
            {"value": "86194", "date": "2023-02-15"},
            {"value": "60667", "date": "2023-02-16"},
            {"value": "47388", "date": "2023-02-17"},
            {"value": "36467", "date": "2023-02-18"},
            {"value": "18503", "date": "2023-02-19"},
            {"value": "36755", "date": "2023-02-20"},
            {"value": "58547", "date": "2023-02-21"},
            {"value": "53145", "date": "2023-02-22"},
            {"value": "52704", "date": "2023-02-23"},
            {"value": "67832", "date": "2023-02-24"},
            {"value": "76956", "date": "2023-02-25"},
            {"value": "58734", "date": "2023-02-26"},
            {"value": "72518", "date": "2023-02-27"},
            {"value": "69151", "date": "2023-02-28"},
            {"value": "77559", "date": "2023-03-01"},
            {"value": "68680", "date": "2023-03-02"},
            {"value": "81972", "date": "2023-03-03"},
            {"value": "97320", "date": "2023-03-04"},
            {"value": "45253", "date": "2023-03-05"},
            {"value": "54197", "date": "2023-03-06"},
            {"value": "53021", "date": "2023-03-07"},
        ],
    }
}
